@@ -122,7 +122,7 @@ class KubernetesItem(Item):
             self.attributes['manifest_file'].endswith(".yaml") or
             self.attributes['manifest_file'].endswith(".yml")
         ):
-            user_manifest = yaml.load(content_processor(self))
+            user_manifest = yaml.load(content_processor(self), Loader=yaml.SafeLoader)
         elif self.attributes['manifest_file'].endswith(".json"):
             user_manifest = json.loads(content_processor(self))
 
@@ -131,7 +131,7 @@ class KubernetesItem(Item):
                 'apiVersion': self.KUBERNETES_APIVERSION,
                 'kind': self.KIND,
                 'metadata': {
-                    'name': self.name.split("/", 1)[-1],
+                    'name': self.name.split("/")[-1],
                 },
             },
             user_manifest,
@@ -227,9 +227,25 @@ class KubernetesRawItem(KubernetesItem):
     BUNDLE_ATTRIBUTE_NAME = "k8s_raw"
     ITEM_TYPE_NAME = "k8s_raw"
     KUBERNETES_APIVERSION = None
-    NAME_REGEX = r"^([a-z0-9-\.]{1,253}/)?[a-zA-Z0-9-\.]{1,253}/[a-z0-9-\.]{1,253}$"
+    NAME_REGEX = r"^([a-z0-9-\.]{1,253})?/[a-zA-Z0-9-\.]{1,253}/[a-z0-9-\.]{1,253}$"
     NAME_REGEX_COMPILED = re.compile(NAME_REGEX)
 
+    def _check_bundle_collisions(self, items):
+        super(KubernetesRawItem, self)._check_bundle_collisions(items)
+        for item in items:
+            if item == self or not isinstance(item, KubernetesItem):
+                continue
+            if item.KIND == self.KIND and item.resource_name == self.resource_name:
+                raise BundleError(_(
+                    "duplicate definition of {item} (from bundle {bundle}) "
+                    "as {item2} (from bundle {bundle2}) on {node}"
+                ).format(
+                    item=self.id,
+                    bundle=self.bundle.name,
+                    item2=item.id,
+                    bundle2=item.bundle.name,
+                ))
+
     def get_auto_deps(self, items):
         deps = super(KubernetesRawItem, self).get_auto_deps(items)
         for item in items:
@@ -242,38 +258,7 @@ class KubernetesRawItem(KubernetesItem):
 
     @property
     def KIND(self):
-        name = self.name.split("/", 2)[1]
-        if name.lower() in (
-            "clusterrole",
-            "clusterrolebinding",
-            "configmap",
-            "cronjob",
-            "customresourcedefinition",
-            "daemonset",
-            "deployment",
-            "ingress",
-            "namespace",
-            "persistentvolumeclaim",
-            "service",
-            "secret",
-            "statefulset",
-        ):
-            raise BundleError(_(
-                "Kind of {item_type}:{name} (bundle '{bundle}') "
-                "on {node} clashes with builtin k8s_* item"
-            ).format(
-                item_type=self.ITEM_TYPE_NAME,
-                name=self.name,
-                bundle=self.bundle.name,
-                node=self.bundle.node.name,
-                regex=self.NAME_REGEX,
-            ))
-        else:
-            return name
-
-    @property
-    def resource_name(self):
-        return self.name.split("/", 2)[2]
+        return self.name.split("/", 2)[1]
 
 
 class KubernetesClusterRole(KubernetesItem):
@@ -405,7 +390,7 @@ class KubernetesNetworkPolicy(KubernetesItem):
     KIND = "NetworkPolicy"
     KUBERNETES_APIVERSION = "networking.k8s.io/v1"
     ITEM_TYPE_NAME = "k8s_networkpolicy"
-    NAME_REGEX = r"^([a-z0-9-\.]{1,253}/)?[a-z0-9-\.]{1,253}$"
+    NAME_REGEX = r"^([a-z0-9-\.]{1,253})?/[a-z0-9-\.]{1,253}$"
     NAME_REGEX_COMPILED = re.compile(NAME_REGEX)
 
 
