@@ -10,7 +10,6 @@ class SnapPkg(Pkg):
     """
     A package installed by snap.
     """
-    BLOCK_CONCURRENT = ["pkg_snap"]
     BUNDLE_ATTRIBUTE_NAME = "pkg_snap"
     ITEM_TYPE_NAME = "pkg_snap"
 
@@ -20,7 +19,7 @@ class SnapPkg(Pkg):
             yield "{}:{}".format(self.ITEM_TYPE_NAME, line.split()[0].split(" ")[0])
 
     def pkg_install(self):
-        self.node.run("snap install {}".format(quote(self.name)))
+        self.node.run("snap install {}".format(quote(self.name)), may_fail=True)
 
     def pkg_installed(self):
         result = self.node.run(
@@ -30,4 +29,4 @@ class SnapPkg(Pkg):
         return result.return_code == 0
 
     def pkg_remove(self):
-        self.node.run("snap remove {}".format(quote(self.name)))
+        self.node.run("snap remove {}".format(quote(self.name)), may_fail=True)
