@@ -77,71 +77,71 @@ class SecretProxy(object):
         self.keys = self._load_keys()
         self._call_log = {}
 
-    def _decrypt(self, cryptotext=None, key='encrypt'):
+    def _decrypt(self, cryptotext=None, key=None):
         """
         Decrypts a given encrypted password.
         """
         if environ.get("BW_VAULT_DUMMY_MODE", "0") != "0":
             return "decrypted text"
-        try:
-            key = self.keys[key]
-        except KeyError:
-            raise FaultUnavailable(_(
-                "Key '{key}' not available for decryption of the following cryptotext, "
-                "check your {file}: {cryptotext}"
-            ).format(
-                cryptotext=cryptotext,
-                file=FILENAME_SECRETS,
-                key=key,
-            ))
 
-        return Fernet(key).decrypt(cryptotext.encode('utf-8')).decode('utf-8')
+        key, cryptotext = self._determine_key_to_use(cryptotext.encode('utf-8'), key, cryptotext)
+        return Fernet(key).decrypt(cryptotext).decode('utf-8')
 
-    def _decrypt_file(self, source_path=None, key='encrypt'):
+    def _decrypt_file(self, source_path=None, key=None):
         """
         Decrypts the file at source_path (relative to data/) and
         returns the plaintext as unicode.
         """
         if environ.get("BW_VAULT_DUMMY_MODE", "0") != "0":
             return "decrypted file"
-        try:
-            key = self.keys[key]
-        except KeyError:
-            raise FaultUnavailable(_(
-                "Key '{key}' not available for decryption of the following file, "
-                "check your {file}: {source_path}"
-            ).format(
-                file=FILENAME_SECRETS,
-                key=key,
-                source_path=source_path,
-            ))
+
+        cryptotext = get_file_contents(join(self.repo.data_dir, source_path))
+        key, cryptotext = self._determine_key_to_use(cryptotext, key, source_path)
 
         f = Fernet(key)
-        return f.decrypt(get_file_contents(join(self.repo.data_dir, source_path))).decode('utf-8')
+        return f.decrypt(cryptotext).decode('utf-8')
 
-    def _decrypt_file_as_base64(self, source_path=None, key='encrypt'):
+    def _decrypt_file_as_base64(self, source_path=None, key=None):
         """
         Decrypts the file at source_path (relative to data/) and
         returns the plaintext as base64.
         """
         if environ.get("BW_VAULT_DUMMY_MODE", "0") != "0":
             return b64encode("decrypted file as base64").decode('utf-8')
+
+        cryptotext = get_file_contents(join(self.repo.data_dir, source_path))
+        key, cryptotext = self._determine_key_to_use(cryptotext, key, source_path)
+
+        f = Fernet(key)
+        return b64encode(f.decrypt(cryptotext)).decode('utf-8')
+
+    def _determine_key_to_use(self, cryptotext, key, entity_description):
+        key_delim = cryptotext.find(b'$')
+        if key_delim > -1:
+            key_from_text = cryptotext[:key_delim].decode('utf-8')
+            cryptotext = cryptotext[key_delim + 1:]
+        else:
+            key_from_text = None
+
+        if key is None:
+            if key_from_text is not None:
+                key = key_from_text
+            else:
+                key = 'encrypt'
+
         try:
             key = self.keys[key]
         except KeyError:
             raise FaultUnavailable(_(
-                "Key '{key}' not available for decryption of the following file, "
-                "check your {file}: {source_path}"
+                "Key '{key}' not available for decryption of the following entity, "
+                "check your {file}: {entity_description}"
             ).format(
                 file=FILENAME_SECRETS,
                 key=key,
-                source_path=source_path,
+                entity_description=entity_description,
             ))
 
-        f = Fernet(key)
-        return b64encode(f.decrypt(get_file_contents(
-            join(self.repo.data_dir, source_path),
-        ))).decode('utf-8')
+        return key, cryptotext
 
     def _generate_human_password(
         self, identifier=None, digits=2, key='generate', per_word=3, words=4,
@@ -209,7 +209,7 @@ class SecretProxy(object):
         PRNG allows for more control over password length and complexity.
         """
         if environ.get("BW_VAULT_DUMMY_MODE", "0") != "0":
-            return "generatedpassword"
+            return ("generatedpassword"*length)[:length]
 
         prng = self._get_prng(identifier, key)
 
@@ -219,6 +219,13 @@ class SecretProxy(object):
 
         return "".join([choice_prng(alphabet, prng) for i in range(length)])
 
+    def _generate_random_bytes_as_base64(self, identifier=None, key='generate', length=32):
+        if environ.get("BW_VAULT_DUMMY_MODE", "0") != "0":
+            return b64encode(bytearray([ord("a") for i in range(length)])).decode()
+
+        prng = self._get_prng(identifier, key)
+        return b64encode(bytearray([next(prng) for i in range(length)])).decode()
+
     def _get_prng(self, identifier, key):
         try:
             key_encoded = self.keys[key]
@@ -248,21 +255,21 @@ class SecretProxy(object):
             result[section] = config.get(section, 'key').encode('utf-8')
         return result
 
-    def decrypt(self, cryptotext, key='encrypt'):
+    def decrypt(self, cryptotext, key=None):
         return Fault(
             self._decrypt,
             cryptotext=cryptotext,
             key=key,
         )
 
-    def decrypt_file(self, source_path, key='encrypt'):
+    def decrypt_file(self, source_path, key=None):
         return Fault(
             self._decrypt_file,
             source_path=source_path,
             key=key,
         )
 
-    def decrypt_file_as_base64(self, source_path, key='encrypt'):
+    def decrypt_file_as_base64(self, source_path, key=None):
         return Fault(
             self._decrypt_file_as_base64,
             source_path=source_path,
@@ -274,6 +281,7 @@ class SecretProxy(object):
         Encrypts a given plaintext password and returns a string that can
         be fed into decrypt() to get the password back.
         """
+        key_name = key
         try:
             key = self.keys[key]
         except KeyError:
@@ -284,7 +292,7 @@ class SecretProxy(object):
                 key=key,
             ))
 
-        return Fernet(key).encrypt(plaintext.encode('utf-8')).decode('utf-8')
+        return key_name + '$' + Fernet(key).encrypt(plaintext.encode('utf-8')).decode('utf-8')
 
     def encrypt_file(self, source_path, target_path, key='encrypt'):
         """
@@ -292,6 +300,7 @@ class SecretProxy(object):
         target_path. The source_path is relative to CWD or absolute,
         while target_path is relative to data/.
         """
+        key_name = key
         try:
             key = self.keys[key]
         except KeyError:
@@ -306,6 +315,7 @@ class SecretProxy(object):
         fernet = Fernet(key)
         target_file = join(self.repo.data_dir, target_path)
         with open(target_file, 'wb') as f:
+            f.write(key_name.encode('utf-8') + b'$')
             f.write(fernet.encrypt(plaintext))
         return target_file
 
@@ -333,3 +343,11 @@ class SecretProxy(object):
             length=length,
             symbols=symbols,
         )
+
+    def random_bytes_as_base64_for(self, identifier, key='generate', length=32):
+        return Fault(
+            self._generate_random_bytes_as_base64,
+            identifier=identifier,
+            key=key,
+            length=length,
+        )
