@@ -29,6 +29,19 @@ def test_encrypt(tmpdir):
     assert rcode == 0
 
 
+def test_encrypt_different_key_autodetect(tmpdir):
+    make_repo(tmpdir)
+
+    stdout, stderr, rcode = run("bw debug -c 'print(repo.vault.encrypt(\"test\", key=\"generate\"))'", path=str(tmpdir))
+    assert stderr == b""
+    assert rcode == 0
+
+    stdout, stderr, rcode = run("bw debug -c 'print(repo.vault.decrypt(\"{}\"))'".format(stdout.decode('utf-8').strip()), path=str(tmpdir))
+    assert stdout == b"test\n"
+    assert stderr == b""
+    assert rcode == 0
+
+
 def test_encrypt_file(tmpdir):
     make_repo(tmpdir)
 
@@ -57,6 +70,35 @@ def test_encrypt_file(tmpdir):
     assert rcode == 0
 
 
+def test_encrypt_file_different_key_autodetect(tmpdir):
+    make_repo(tmpdir)
+
+    source_file = join(str(tmpdir), "data", "source")
+    with open(source_file, 'w') as f:
+        f.write("ohai")
+
+    stdout, stderr, rcode = run(
+        "bw debug -c 'repo.vault.encrypt_file(\"{}\", \"{}\", \"{}\")'".format(
+            source_file,
+            "encrypted",
+            "generate",
+        ),
+        path=str(tmpdir),
+    )
+    assert stderr == b""
+    assert rcode == 0
+
+    stdout, stderr, rcode = run(
+        "bw debug -c 'print(repo.vault.decrypt_file(\"{}\"))'".format(
+            "encrypted",
+        ),
+        path=str(tmpdir),
+    )
+    assert stdout == b"ohai\n"
+    assert stderr == b""
+    assert rcode == 0
+
+
 def test_encrypt_file_base64(tmpdir):
     make_repo(tmpdir)
 
@@ -128,3 +170,21 @@ def test_human_password_words(tmpdir):
     assert stdout == b"Xaint-Heep-13\n"
     assert stderr == b""
     assert rcode == 0
+
+
+def test_random_bytes_as_base64(tmpdir):
+    make_repo(tmpdir)
+
+    stdout, stderr, rcode = run("bw debug -c 'print(repo.vault.random_bytes_as_base64_for(\"foo\"))'", path=str(tmpdir))
+    assert stdout == b"rt+Dgv0yA10DS3ux94mmtEg+isChTJvgkfklzmWkvyg=\n"
+    assert stderr == b""
+    assert rcode == 0
+
+
+def test_random_bytes_as_base64_length(tmpdir):
+    make_repo(tmpdir)
+
+    stdout, stderr, rcode = run("bw debug -c 'print(repo.vault.random_bytes_as_base64_for(\"foo\", length=1))'", path=str(tmpdir))
+    assert stdout == b"rg==\n"
+    assert stderr == b""
+    assert rcode == 0
